@@ -1,3 +1,4 @@
+import os
 import subprocess
 from tempfile import TemporaryFile, NamedTemporaryFile
 from StringIO import StringIO
@@ -58,6 +59,9 @@ class AudioSegment(object):
         if isinstance(millisecond, slice):
             start = millisecond.start if millisecond.start is not None else 0
             end = millisecond.stop if millisecond.stop is not None else len(self)
+            
+            start = min(start, len(self))
+            end = min(end, len(self))
         else:
             start = millisecond
             end = millisecond + 1
@@ -71,7 +75,7 @@ class AudioSegment(object):
         missing_frames = (expected_length - len(data)) / self.frame_width
         if missing_frames:
             if missing_frames > self.frame_count(ms=2):
-                raise TooManyMissingFrames("You should never be filling in more than 1 ms with silence here")
+                raise TooManyMissingFrames("You should never be filling in more than 2 ms with silence here, missing frames: %s" % missing_frames)
             silence = audioop.mul(data[:self.frame_width], self.sample_width, 0)
             data += (silence * missing_frames)
         
@@ -170,10 +174,17 @@ class AudioSegment(object):
         input = NamedTemporaryFile(mode='wb')
         input.write(file.read())
         
-        output = TemporaryFile()
+        output = NamedTemporaryFile(mode="w+")
         
         # read stdin / write stdout
-        subprocess.call(['lame', '--silent', '--mp3input', '--decode', input.name, '-'], stdout=output)
+        subprocess.call(['ffmpeg', 
+                         '-y', # always overwrite existing files
+                         "-f", "mp3", "-i", input.name, # input options (filename last)
+                         "-f", "wav", output.name, # output options (filename last)
+                         ], 
+                        
+                        # make ffmpeg shut up
+                        stderr=open(os.devnull))
         
         input.close()
         return cls.from_wav(output)
@@ -203,11 +214,21 @@ class AudioSegment(object):
         wave_data.writeframesraw(self._data)
         wave_data.close()
         
-        if format == 'mp3':
-            subprocess.call(['lame', '--silent',
-                             data.name, '-'], stdout=out_f)
-        elif format == 'wav':
-            out_f.write(open(data.name).read())
+        
+        output = NamedTemporaryFile(mode="w+")
+        
+        # read stdin / write stdout
+        subprocess.call(['ffmpeg', 
+                         '-y', # always overwrite existing files
+                         "-f", "wav", "-i", data.name, # input options (filename last)
+                         "-f", format, output.name, # output options (filename last)
+                         ], 
+                        
+                        # make ffmpeg shut up
+                        stderr=open(os.devnull))
+        
+        output.seek(0)
+        out_f.write(output.read())
         
         data.unlink(data.name)
         out_f.seek(0)
